==> huaweicloudsdkiam-3.0.52-py2.py3-none-any.whl: huaweicloudsdkiam/v3/model/version_mediatypes.py <==
# coding: utf-8

import re
import six





class VersionMediatypes:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'type': 'str',
        'base': 'str'
    }

    attribute_map = {
        'type': 'type',
        'base': 'base'
    }

    def __init__(self, type=None, base=None):
        """VersionMediatypes - a model defined in huaweicloud sdk"""
        
        

        self._type = None
        self._base = None
        self.discriminator = None

        self.type = type
        self.base = base

    @property
    def type(self):
        """Gets the type of this VersionMediatypes.

        媒体类型。

        :return: The type of this VersionMediatypes.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this VersionMediatypes.

        媒体类型。

        :param type: The type of this VersionMediatypes.
        :type: str
        """
        self._type = type

    @property
    def base(self):
        """Gets the base of this VersionMediatypes.

        基础类型。

        :return: The base of this VersionMediatypes.
        :rtype: str
        """
        return self._base

    @base.setter
    def base(self, base):
        """Sets the base of this VersionMediatypes.

        基础类型。

        :param base: The base of this VersionMediatypes.
        :type: str
        """
        self._base = base

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VersionMediatypes):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkiam-3.0.54-py2.py3-none-any.whl: huaweicloudsdkiam/v3/model/version_mediatypes.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class VersionMediatypes:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'type': 'str',
        'base': 'str'
    }

    attribute_map = {
        'type': 'type',
        'base': 'base'
    }

    def __init__(self, type=None, base=None):
        """VersionMediatypes - a model defined in huaweicloud sdk"""
        
        

        self._type = None
        self._base = None
        self.discriminator = None

        self.type = type
        self.base = base

    @property
    def type(self):
        """Gets the type of this VersionMediatypes.

        媒体类型。

        :return: The type of this VersionMediatypes.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this VersionMediatypes.

        媒体类型。

        :param type: The type of this VersionMediatypes.
        :type: str
        """
        self._type = type

    @property
    def base(self):
        """Gets the base of this VersionMediatypes.

        基础类型。

        :return: The base of this VersionMediatypes.
        :rtype: str
        """
        return self._base

    @base.setter
    def base(self, base):
        """Sets the base of this VersionMediatypes.

        基础类型。

        :param base: The base of this VersionMediatypes.
        :type: str
        """
        self._base = base

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(sanitize_for_serialization(self))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VersionMediatypes):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
